@@ -1,4 +1,4 @@
-from composio import Action, App, Tag, Trigger, WorkspaceType
+from composio import Action, App, Tag, Trigger, WorkspaceType, action
 
 from composio_camel.toolset import ComposioToolSet
 
@@ -9,5 +9,6 @@ __all__ = (
     "Tag",
     "ComposioToolSet",
     "WorkspaceType",
+    "action",
     "Trigger",
 )
